@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -60,6 +60,8 @@ import org.osgi.service.event.EventAdmin;
 import org.osgi.service.event.EventConstants;
 import org.osgi.service.event.EventHandler;
 import org.osgi.util.tracker.ServiceTracker;
+import com.openexchange.config.ConfigurationService;
+import com.openexchange.event.EventFactoryService;
 import com.openexchange.exceptions.osgi.ComponentRegistration;
 import com.openexchange.push.PushException;
 import com.openexchange.push.PushManagerService;
@@ -73,7 +75,7 @@ import com.openexchange.threadpool.ThreadPoolService;
 
 /**
  * {@link PushActivator} - The activator for push bundle.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class PushActivator implements BundleActivator {
@@ -92,7 +94,7 @@ public final class PushActivator implements BundleActivator {
     }
 
     public void start(final BundleContext context) throws Exception {
-        final org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(PushActivator.class);
+        final org.apache.commons.logging.Log log = com.openexchange.log.Log.valueOf(com.openexchange.log.Log.valueOf(com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(PushActivator.class))));
         try {
             if (log.isInfoEnabled()) {
                 log.info("starting bundle: com.openexchange.push");
@@ -108,9 +110,18 @@ public final class PushActivator implements BundleActivator {
             trackers = new ArrayList<ServiceTracker>(4);
             PushManagerRegistry.init();
             trackers.add(new ServiceTracker(context, PushManagerService.class.getName(), new PushManagerServiceTracker(context)));
+            trackers.add(new ServiceTracker(context, ConfigurationService.class.getName(), new WhitelistServiceTracker(context)));
             /*
              * Thread pool service tracker
              */
+            trackers.add(new ServiceTracker(context, ConfigurationService.class.getName(), new RegistryServiceTrackerCustomizer<ConfigurationService>(
+                context,
+                ServiceRegistry.getInstance(),
+                ConfigurationService.class)));
+            trackers.add(new ServiceTracker(context, EventFactoryService.class.getName(), new RegistryServiceTrackerCustomizer<EventFactoryService>(
+                context,
+                ServiceRegistry.getInstance(),
+                EventFactoryService.class)));
             trackers.add(new ServiceTracker(context, ThreadPoolService.class.getName(), new RegistryServiceTrackerCustomizer<ThreadPoolService>(
                     context,
                     ServiceRegistry.getInstance(),
@@ -125,7 +136,7 @@ public final class PushActivator implements BundleActivator {
             /*
              * Register event handler to detect removed sessions
              */
-            final Dictionary<Object, Object> serviceProperties = new Hashtable<Object, Object>(1);
+            final Dictionary<String, Object> serviceProperties = new Hashtable<String, Object>(1);
             serviceProperties.put(EventConstants.EVENT_TOPIC, SessiondEventConstants.getAllTopics());
             eventHandlerRegistration = context.registerService(EventHandler.class.getName(), new PushEventHandler(), serviceProperties);
         } catch (final Exception e) {
@@ -135,7 +146,7 @@ public final class PushActivator implements BundleActivator {
     }
 
     public void stop(final BundleContext context) throws Exception {
-        final org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(PushActivator.class);
+        final org.apache.commons.logging.Log log = com.openexchange.log.Log.valueOf(com.openexchange.log.Log.valueOf(com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(PushActivator.class))));
         try {
             if (log.isInfoEnabled()) {
                 log.info("stopping bundle: com.openexchange.push");
