@@ -28,7 +28,7 @@
  *    http://www.open-xchange.com/EN/developer/. The contributing author shall be
  *    given Attribution for the derivative code and a license granting use.
  *
- *     Copyright (C) 2004-2010 Open-Xchange, Inc.
+ *     Copyright (C) 2004-2012 Open-Xchange, Inc.
  *     Mail: info@open-xchange.com
  *
  *
@@ -57,7 +57,7 @@ import com.openexchange.push.internal.PushManagerRegistry;
 
 /**
  * {@link PushManagerServiceTracker} - The service tracker for push managers.
- * 
+ *
  * @author <a href="mailto:thorben.betten@open-xchange.com">Thorben Betten</a>
  */
 public final class PushManagerServiceTracker implements ServiceTrackerCustomizer {
@@ -66,7 +66,7 @@ public final class PushManagerServiceTracker implements ServiceTrackerCustomizer
 
     /**
      * Initializes a new {@link PushManagerServiceTracker}.
-     * 
+     *
      * @param context The bundle context
      */
     public PushManagerServiceTracker(final BundleContext context) {
@@ -77,7 +77,7 @@ public final class PushManagerServiceTracker implements ServiceTrackerCustomizer
     public Object addingService(final ServiceReference reference) {
         final Object service = context.getService(reference);
         if (service instanceof PushManagerService && PushManagerRegistry.getInstance().addPushManager((PushManagerService) service)) {
-            final org.apache.commons.logging.Log log = org.apache.commons.logging.LogFactory.getLog(PushManagerServiceTracker.class);
+            final org.apache.commons.logging.Log log = com.openexchange.log.Log.valueOf(com.openexchange.log.Log.valueOf(com.openexchange.log.Log.valueOf(org.apache.commons.logging.LogFactory.getLog(PushManagerServiceTracker.class))));
             log.info("Registered push manager: " + service.getClass().getName());
             return service;
         }
